from pyhausbus.HausBusUtils import LOGGER
from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.de.hausbus.homeassistant.proxy.gateway.params.EErrorCode import EErrorCode
from pyhausbus.de.hausbus.homeassistant.proxy.gateway.data.Configuration import Configuration
from pyhausbus.de.hausbus.homeassistant.proxy.gateway.params.MOptions import MOptions
from pyhausbus.de.hausbus.homeassistant.proxy.gateway.data.BusTiming import BusTiming
from pyhausbus.de.hausbus.homeassistant.proxy.gateway.data.ConnectedDevices import ConnectedDevices

class Gateway(ABusFeature):
  CLASS_ID:int = 176

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return Gateway(HausBusUtils.getObjectId(deviceId, 176, instanceId))

  """
  @param errorCode .
  """
  def evError(self, errorCode:EErrorCode):
    LOGGER.debug("evError"+" errorCode = "+str(errorCode))
    hbCommand = HausBusCommand(self.objectId, 255, "evError")
    hbCommand.addByte(errorCode.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getConfiguration(self):
    LOGGER.debug("getConfiguration")
    hbCommand = HausBusCommand(self.objectId, 0, "getConfiguration")
    ResultWorker()._setResultInfo(Configuration,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param options Reservierte Bits muessen immer deaktiviert sein. Das Aktivieren eines reservierten Bits fuehrt nach dem Neustart des Controllers zu den Standart-Einstellungen..
  """
  def setConfiguration(self, options:MOptions):
    LOGGER.debug("setConfiguration"+" options = "+str(options))
    hbCommand = HausBusCommand(self.objectId, 1, "setConfiguration")
    hbCommand.addByte(options.getValue())
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def checkBusTiming(self):
    LOGGER.debug("checkBusTiming")
    hbCommand = HausBusCommand(self.objectId, 2, "checkBusTiming")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getBusTiming(self):
    LOGGER.debug("getBusTiming")
    hbCommand = HausBusCommand(self.objectId, 3, "getBusTiming")
    ResultWorker()._setResultInfo(BusTiming,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param timings .
  """
  def BusTiming(self, timings):
    LOGGER.debug("BusTiming"+" timings = "+str(timings))
    hbCommand = HausBusCommand(self.objectId, 129, "BusTiming")
    hbCommand.addMap(timings)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param options enabled: Dies Gateway ist aktiv und leitet Nachrichten weiter\r\npreferLoxone: Gateway kommuniziert bevorzugt im Loxone-Protokoll.
  """
  def Configuration(self, options:MOptions):
    LOGGER.debug("Configuration"+" options = "+str(options))
    hbCommand = HausBusCommand(self.objectId, 128, "Configuration")
    hbCommand.addByte(options.getValue())
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def resetBusTiming(self):
    LOGGER.debug("resetBusTiming")
    hbCommand = HausBusCommand(self.objectId, 4, "resetBusTiming")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getConnectedDevices(self):
    LOGGER.debug("getConnectedDevices")
    hbCommand = HausBusCommand(self.objectId, 5, "getConnectedDevices")
    ResultWorker()._setResultInfo(ConnectedDevices,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param deviceIds .
  """
  def ConnectedDevices(self, deviceIds):
    LOGGER.debug("ConnectedDevices"+" deviceIds = "+str(deviceIds))
    hbCommand = HausBusCommand(self.objectId, 130, "ConnectedDevices")
    hbCommand.addMap(deviceIds)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param messagesPerMinute Anzahl der Nachrichten pro Sekunde.
  @param bytesPerMinute Anzahl der Datenbytes pro Sekunde.
  """
  def evGatewayLoad(self, messagesPerMinute:int, bytesPerMinute:int):
    LOGGER.debug("evGatewayLoad"+" messagesPerMinute = "+str(messagesPerMinute)+" bytesPerMinute = "+str(bytesPerMinute))
    hbCommand = HausBusCommand(self.objectId, 200, "evGatewayLoad")
    hbCommand.addWord(messagesPerMinute)
    hbCommand.addDWord(bytesPerMinute)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")





import pyhausbus.HausBusUtils as HausBusUtils

class EvGatewayLoad:
  CLASS_ID = 176
  FUNCTION_ID = 200

  def __init__(self,messagesPerMinute:int, bytesPerMinute:int):
    self.messagesPerMinute=messagesPerMinute
    self.bytesPerMinute=bytesPerMinute


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvGatewayLoad(HausBusUtils.bytesToWord(dataIn, offset), HausBusUtils.bytesToDWord(dataIn, offset))

  def __str__(self):
    return f"EvGatewayLoad(messagesPerMinute={self.messagesPerMinute}, bytesPerMinute={self.bytesPerMinute})"

  '''
  @param messagesPerMinute Anzahl der Nachrichten pro Sekunde.
  '''
  def getMessagesPerMinute(self):
    return self.messagesPerMinute

  '''
  @param bytesPerMinute Anzahl der Datenbytes pro Sekunde.
  '''
  def getBytesPerMinute(self):
    return self.bytesPerMinute






from pyhausbus.HausBusUtils import LOGGER
from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.de.hausbus.homeassistant.proxy.digitalPort.data.Configuration import Configuration
from pyhausbus.de.hausbus.homeassistant.proxy.digitalPort.params.EPin import EPin
from pyhausbus.de.hausbus.homeassistant.proxy.digitalPort.params.EErrorCode import EErrorCode

class DigitalPort(ABusFeature):
  CLASS_ID:int = 15

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return DigitalPort(HausBusUtils.getObjectId(deviceId, 15, instanceId))

  """
  """
  def getConfiguration(self):
    LOGGER.debug("getConfiguration")
    hbCommand = HausBusCommand(self.objectId, 0, "getConfiguration")
    ResultWorker()._setResultInfo(Configuration,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param pin0 .
  @param pin1 .
  @param pin2 .
  @param pin3 .
  @param pin4 .
  @param pin5 .
  @param pin6 .
  @param pin7 .
  """
  def setConfiguration(self, pin0:EPin, pin1:EPin, pin2:EPin, pin3:EPin, pin4:EPin, pin5:EPin, pin6:EPin, pin7:EPin):
    LOGGER.debug("setConfiguration"+" pin0 = "+str(pin0)+" pin1 = "+str(pin1)+" pin2 = "+str(pin2)+" pin3 = "+str(pin3)+" pin4 = "+str(pin4)+" pin5 = "+str(pin5)+" pin6 = "+str(pin6)+" pin7 = "+str(pin7))
    hbCommand = HausBusCommand(self.objectId, 1, "setConfiguration")
    hbCommand.addByte(pin0.value)
    hbCommand.addByte(pin1.value)
    hbCommand.addByte(pin2.value)
    hbCommand.addByte(pin3.value)
    hbCommand.addByte(pin4.value)
    hbCommand.addByte(pin5.value)
    hbCommand.addByte(pin6.value)
    hbCommand.addByte(pin7.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param pin0 .
  @param pin1 .
  @param pin2 .
  @param pin3 .
  @param pin4 .
  @param pin5 .
  @param pin6 .
  @param pin7 .
  """
  def Configuration(self, pin0:EPin, pin1:EPin, pin2:EPin, pin3:EPin, pin4:EPin, pin5:EPin, pin6:EPin, pin7:EPin):
    LOGGER.debug("Configuration"+" pin0 = "+str(pin0)+" pin1 = "+str(pin1)+" pin2 = "+str(pin2)+" pin3 = "+str(pin3)+" pin4 = "+str(pin4)+" pin5 = "+str(pin5)+" pin6 = "+str(pin6)+" pin7 = "+str(pin7))
    hbCommand = HausBusCommand(self.objectId, 128, "Configuration")
    hbCommand.addByte(pin0.value)
    hbCommand.addByte(pin1.value)
    hbCommand.addByte(pin2.value)
    hbCommand.addByte(pin3.value)
    hbCommand.addByte(pin4.value)
    hbCommand.addByte(pin5.value)
    hbCommand.addByte(pin6.value)
    hbCommand.addByte(pin7.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param errorCode .
  """
  def evError(self, errorCode:EErrorCode):
    LOGGER.debug("evError"+" errorCode = "+str(errorCode))
    hbCommand = HausBusCommand(self.objectId, 255, "evError")
    hbCommand.addByte(errorCode.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")





from pyhausbus.HausBusUtils import LOGGER
from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.de.hausbus.homeassistant.proxy.modBusMaster.data.Configuration import Configuration
from pyhausbus.de.hausbus.homeassistant.proxy.modBusMaster.params.ESensorType import ESensorType

class ModBusMaster(ABusFeature):
  CLASS_ID:int = 45

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return ModBusMaster(HausBusUtils.getObjectId(deviceId, 45, instanceId))

  """
  @param idx index of the configuration slot.
  """
  def getConfiguration(self, idx:int):
    LOGGER.debug("getConfiguration"+" idx = "+str(idx))
    hbCommand = HausBusCommand(self.objectId, 0, "getConfiguration")
    hbCommand.addByte(idx)
    ResultWorker()._setResultInfo(Configuration,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param idx index of the configuration slot.
  @param node Geraeteadresse im ModBus.
  @param sensorType Supported Power-Meter SDM630 / SDM72D / SDM72V2 / ORWE517.
  """
  def setConfiguration(self, idx:int, node:int, sensorType:ESensorType):
    LOGGER.debug("setConfiguration"+" idx = "+str(idx)+" node = "+str(node)+" sensorType = "+str(sensorType))
    hbCommand = HausBusCommand(self.objectId, 1, "setConfiguration")
    hbCommand.addByte(idx)
    hbCommand.addByte(node)
    hbCommand.addByte(sensorType.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param idx index of the configuration slot.
  @param node device node on ModBus.
  @param sensorType Supported Power-Meter SDM630 / SDM72D / SDM72V2 / ORWE517.
  """
  def Configuration(self, idx:int, node:int, sensorType:ESensorType):
    LOGGER.debug("Configuration"+" idx = "+str(idx)+" node = "+str(node)+" sensorType = "+str(sensorType))
    hbCommand = HausBusCommand(self.objectId, 128, "Configuration")
    hbCommand.addByte(idx)
    hbCommand.addByte(node)
    hbCommand.addByte(sensorType.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")





import pyhausbus.HausBusUtils as HausBusUtils

class Stop:
  CLASS_ID = 18
  FUNCTION_ID = 4

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return Stop()

  def __str__(self):
    return f"Stop()"






import pyhausbus.HausBusUtils as HausBusUtils

class GetEnabled:
  CLASS_ID = 16
  FUNCTION_ID = 4

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return GetEnabled()

  def __str__(self):
    return f"GetEnabled()"






from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.MLogicalButtonMask import MLogicalButtonMask
from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.ESlotType import ESlotType
import pyhausbus.HausBusUtils as HausBusUtils

class SetConfiguration:
  CLASS_ID = 0
  FUNCTION_ID = 6

  def __init__(self,startupDelay:int, logicalButtonMask:MLogicalButtonMask, deviceId:int, reportMemoryStatusTime:int, slotType0:ESlotType, slotType1:ESlotType, slotType2:ESlotType, slotType3:ESlotType, slotType4:ESlotType, slotType5:ESlotType, slotType6:ESlotType, slotType7:ESlotType):
    self.startupDelay=startupDelay
    self.logicalButtonMask=logicalButtonMask
    self.deviceId=deviceId
    self.reportMemoryStatusTime=reportMemoryStatusTime
    self.slotType0=slotType0
    self.slotType1=slotType1
    self.slotType2=slotType2
    self.slotType3=slotType3
    self.slotType4=slotType4
    self.slotType5=slotType5
    self.slotType6=slotType6
    self.slotType7=slotType7


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SetConfiguration(HausBusUtils.bytesToInt(dataIn, offset), MLogicalButtonMask._fromBytes(dataIn, offset), HausBusUtils.bytesToWord(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), ESlotType._fromBytes(dataIn, offset), ESlotType._fromBytes(dataIn, offset), ESlotType._fromBytes(dataIn, offset), ESlotType._fromBytes(dataIn, offset), ESlotType._fromBytes(dataIn, offset), ESlotType._fromBytes(dataIn, offset), ESlotType._fromBytes(dataIn, offset), ESlotType._fromBytes(dataIn, offset))

  def __str__(self):
    return f"SetConfiguration(startupDelay={self.startupDelay}, logicalButtonMask={self.logicalButtonMask}, deviceId={self.deviceId}, reportMemoryStatusTime={self.reportMemoryStatusTime}, slotType0={self.slotType0}, slotType1={self.slotType1}, slotType2={self.slotType2}, slotType3={self.slotType3}, slotType4={self.slotType4}, slotType5={self.slotType5}, slotType6={self.slotType6}, slotType7={self.slotType7})"

  '''
  @param startupDelay a 10ms.
  '''
  def getStartupDelay(self):
    return self.startupDelay

  '''
  @param logicalButtonMask jedes Bit enspricht einem logischem Taster.
  '''
  def getLogicalButtonMask(self) -> MLogicalButtonMask:
    return self.logicalButtonMask

  '''
  @param deviceId .
  '''
  def getDeviceId(self):
    return self.deviceId

  '''
  @param reportMemoryStatusTime Zeitinterval in Minuten1-255min.
  '''
  def getReportMemoryStatusTime(self):
    return self.reportMemoryStatusTime

  '''
  @param slotType0 .
  '''
  def getSlotType0(self):
    return self.slotType0

  '''
  @param slotType1 .
  '''
  def getSlotType1(self):
    return self.slotType1

  '''
  @param slotType2 .
  '''
  def getSlotType2(self):
    return self.slotType2

  '''
  @param slotType3 .
  '''
  def getSlotType3(self):
    return self.slotType3

  '''
  @param slotType4 .
  '''
  def getSlotType4(self):
    return self.slotType4

  '''
  @param slotType5 .
  '''
  def getSlotType5(self):
    return self.slotType5

  '''
  @param slotType6 .
  '''
  def getSlotType6(self):
    return self.slotType6

  '''
  @param slotType7 .
  '''
  def getSlotType7(self):
    return self.slotType7






import pyhausbus.HausBusUtils as HausBusUtils
class MOptionMask:

  def setInverted(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 0, self.value)
    return self

  def isInverted(self):
    return HausBusUtils.isBitSet(0, self.value)
  def setPulldown(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 1, self.value)
    return self

  def isPulldown(self):
    return HausBusUtils.isBitSet(1, self.value)
  def setReserved1(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 2, self.value)
    return self

  def isReserved1(self):
    return HausBusUtils.isBitSet(2, self.value)
  def setReserved2(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 3, self.value)
    return self

  def isReserved2(self):
    return HausBusUtils.isBitSet(3, self.value)
  def setReserved3(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 4, self.value)
    return self

  def isReserved3(self):
    return HausBusUtils.isBitSet(4, self.value)
  def setReserved4(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 5, self.value)
    return self

  def isReserved4(self):
    return HausBusUtils.isBitSet(5, self.value)
  def setReserved5(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 6, self.value)
    return self

  def isReserved5(self):
    return HausBusUtils.isBitSet(6, self.value)
  def setReserved6(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 7, self.value)
    return self

  def isReserved6(self):
    return HausBusUtils.isBitSet(7, self.value)
  def __init__(self, value:int):
    self.value = value

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    return MOptionMask(HausBusUtils.bytesToInt(data, offset))



  def getValue(self):
    return self.value
  def getEntryNames(self):
    result = []
    result.append("Inverted")
    result.append("Pulldown")
    result.append("Reserved1")
    result.append("Reserved2")
    result.append("Reserved3")
    result.append("Reserved4")
    result.append("Reserved5")
    result.append("Reserved6")
    return result
  def setEntry(self,name:str, setValue:bool):
    if (name == "Inverted"):
      self.setInverted(setValue)
    if (name == "Pulldown"):
      self.setPulldown(setValue)
    if (name == "Reserved1"):
      self.setReserved1(setValue)
    if (name == "Reserved2"):
      self.setReserved2(setValue)
    if (name == "Reserved3"):
      self.setReserved3(setValue)
    if (name == "Reserved4"):
      self.setReserved4(setValue)
    if (name == "Reserved5"):
      self.setReserved5(setValue)
    if (name == "Reserved6"):
      self.setReserved6(setValue)

  def __str__(self):
    return f"MOptionMask(Inverted = {self.isInverted()}, Pulldown = {self.isPulldown()}, Reserved1 = {self.isReserved1()}, Reserved2 = {self.isReserved2()}, Reserved3 = {self.isReserved3()}, Reserved4 = {self.isReserved4()}, Reserved5 = {self.isReserved5()}, Reserved6 = {self.isReserved6()})"






import pyhausbus.HausBusUtils as HausBusUtils

class EvData:
  CLASS_ID = 43
  FUNCTION_ID = 201

  def __init__(self,tagID:int):
    self.tagID=tagID


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvData(HausBusUtils.bytesToDWord(dataIn, offset))

  def __str__(self):
    return f"EvData(tagID={self.tagID})"

  '''
  @param tagID ID of the detected RFID tag.
  '''
  def getTagID(self):
    return self.tagID






import pyhausbus.HausBusUtils as HausBusUtils
from enum import Enum

class EErrorCode(Enum):
  NO_ERROR=0
  TIMEOUT=1
  NOT_SUPPORTED_SENSOR_OBJECT=2
  NOT_SUPPORTED_ACTOR_OBJECT=3
  SER_UNKNOWN=-1

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    checkValue = HausBusUtils.bytesToInt(data, offset)
    for act in EErrorCode.__members__.values():
      if (act.value == checkValue):
        return act

    return EErrorCode.SER_UNKNOWN






from pyhausbus.HausBusUtils import LOGGER
from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils

class IRSensor(ABusFeature):
  CLASS_ID:int = 33

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return IRSensor(HausBusUtils.getObjectId(deviceId, 33, instanceId))

  """
  """
  def off(self):
    LOGGER.debug("off")
    hbCommand = HausBusCommand(self.objectId, 0, "off")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def on(self):
    LOGGER.debug("on")
    hbCommand = HausBusCommand(self.objectId, 1, "on")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param address IR Adresse.
  @param command IR Kommando.
  """
  def evClicked(self, address:int, command:int):
    LOGGER.debug("evClicked"+" address = "+str(address)+" command = "+str(command))
    hbCommand = HausBusCommand(self.objectId, 202, "evClicked")
    hbCommand.addWord(address)
    hbCommand.addWord(command)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def evOff(self):
    LOGGER.debug("evOff")
    hbCommand = HausBusCommand(self.objectId, 200, "evOff")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def evOn(self):
    LOGGER.debug("evOn")
    hbCommand = HausBusCommand(self.objectId, 201, "evOn")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param address IR Adresse.
  @param command IR Kommando.
  """
  def evHoldStart(self, address:int, command:int):
    LOGGER.debug("evHoldStart"+" address = "+str(address)+" command = "+str(command))
    hbCommand = HausBusCommand(self.objectId, 203, "evHoldStart")
    hbCommand.addWord(address)
    hbCommand.addWord(command)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param address IR Adresse.
  @param command IR Kommando.
  """
  def evHoldEnd(self, address:int, command:int):
    LOGGER.debug("evHoldEnd"+" address = "+str(address)+" command = "+str(command))
    hbCommand = HausBusCommand(self.objectId, 204, "evHoldEnd")
    hbCommand.addWord(address)
    hbCommand.addWord(command)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")





from pyhausbus.HausBusUtils import LOGGER
from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.WeekTime import WeekTime

class Wetter(ABusFeature):
  CLASS_ID:int = 2

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return Wetter(HausBusUtils.getObjectId(deviceId, 2, instanceId))

  """
  """
  def getWeather(self):
    LOGGER.debug("getWeather")
    hbCommand = HausBusCommand(self.objectId, 5, "getWeather")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param humidity Luftfeuchtigkeit.
  @param pressure Luftdruck.
  @param temp Temperatur.
  @param sunrise Zeitpunkt vom Sonnenaufgang.
  @param sunset Zeitpunkt vom Sonnenuntergang.
  @param text Beschreibung.
  """
  def weather(self, humidity:int, pressure:int, temp:int, sunrise:WeekTime=None
, sunset:WeekTime=None
, text:str):
    LOGGER.debug("weather"+" humidity = "+str(humidity)+" pressure = "+str(pressure)+" temp = "+str(temp)+" sunrise = "+str(sunrise)+" sunset = "+str(sunset)+" text = "+str(text))
    hbCommand = HausBusCommand(self.objectId, 128, "weather")
    hbCommand.addByte(humidity)
    hbCommand.addWord(pressure)
    hbCommand.addByte(temp)
    hbCommand.addWord(sunrise.getValue())
    hbCommand.addWord(sunset.getValue())
    hbCommand.addString(text)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")


